Multi-agent runtime management.
Provides [RuntimeSet] for managing a collection of named runtimes,
one per agent. Handles the chicken-and-egg problem of inter-agent
delegation (tools need runtimes, runtimes need tools) by using a
shared Arc<RwLock<HashMap>> that is populated after all runtimes
are constructed.
Structs
- Runtime
SetBuilder - Builder for creating a set of named runtimes from agent profiles.
- Runtime
SetConfig - Configuration for building a [
RuntimeSet]. - Runtime
SetResult - Result of building a runtime set.
Type Aliases
- Runtime
Map - A shared map of named runtimes, keyed by lowercase agent name.